@@ -82,6 +82,7 @@
 #if HAVE_KCRASH
 #include <KCrash>
 #endif
+#include <kcontacts_version.h>
 #include <KContacts/AddressFormat>
 
 #include <QQuickStyle>
@@ -115,6 +116,7 @@ class MatrixBeaconStub : public QObject
 
 void registerKContactsTypes()
 {
+#if KCONTACTS_VERSION < QT_VERSION_CHECK(6, 3, 0)
     // ### this should move into a real QML plugin for KContacts
     qmlRegisterUncreatableMetaObject(KContacts::staticMetaObject, "org.kde.contacts", 1, 0, "KContacts", {});
     qmlRegisterSingletonType("org.kde.contacts", 1, 0, "AddressFormatRepository", [](QQmlEngine *, QJSEngine *jsEngine) -> QJSValue {
@@ -125,6 +127,7 @@ void registerKContactsTypes()
     qRegisterMetaType<KContacts::AddressFormatRepository>();
     qRegisterMetaType<KContacts::AddressFormatPreference>();
     qRegisterMetaType<KContacts::AddressFormatScriptPreference>();
+#endif
 }
 
 void registerKCalendarCoreTypes()
